.. _api:

API
===

.. toctree::
   :maxdepth: 2


.. module:: fnapy_manager

FnapyManager
------------

.. autoclass:: FnapyManager
   :members:
   :inherited-members:


.. module:: connection

FnapyConnection
---------------

.. autoclass:: FnapyConnection
   :members:
   :inherited-members:



.. module:: utils

Request
-------

.. autoclass:: Request
   :members:
   :inherited-members:


Response
--------

.. autoclass:: Response
   :members:
   :inherited-members:


Message
-------

.. autoclass:: Message
   :members:
   :inherited-members:


